@@ -553,9 +553,12 @@ static gboolean prepare_contents (GFile * gfile, DVContents * deb) {
 #if ARCHIVE_VERSION_NUMBER < 3000000
 	archive_read_support_compression_gzip (deb->control_tar);
 	archive_read_support_compression_xz (deb->control_tar);
+	archive_read_support_compression_bzip2 (deb->control_tar);
 #else
 	archive_read_support_filter_gzip (deb->control_tar);
 	archive_read_support_filter_xz (deb->control_tar);
+	archive_read_support_filter_zstd (deb->control_tar);
+	archive_read_support_filter_bzip2 (deb->control_tar);
 #endif
 	archive_read_support_format_tar (deb->control_tar);
 	error_num = ARCHIVE_OK;
@@ -669,9 +672,14 @@ static gboolean prepare_contents (GFile * gfile, DVContents * deb) {
 #if ARCHIVE_VERSION_NUMBER < 3000000
 	archive_read_support_compression_gzip (deb->data_tar);
 	archive_read_support_compression_xz (deb->data_tar);
+	archive_read_support_compression_bzip2 (deb->data_tar);
+	archive_read_support_compression_lzma (deb->data_tar);
 #else
 	archive_read_support_filter_gzip (deb->data_tar);
 	archive_read_support_filter_xz (deb->data_tar);
+	archive_read_support_filter_zstd (deb->data_tar);
+	archive_read_support_filter_bzip2 (deb->data_tar);
+	archive_read_support_filter_lzma (deb->data_tar);
 #endif
 	archive_read_support_format_tar (deb->data_tar);
 	error_num = ARCHIVE_OK;
